==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property attachmentId
 * @property destinationCidr
 * @property prefixListId
 * @property resourceId
 * @property resourceType
 * @property routeOrigin
 * @property state
 */
public data class NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute(
    public val attachmentId: String? = null,
    public val destinationCidr: String? = null,
    public val prefixListId: String? = null,
    public val resourceId: String? = null,
    public val resourceType: String? = null,
    public val routeOrigin: String? = null,
    public val state: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute):
            NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute =
            NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute(
                attachmentId = javaType.attachmentId().map({ args0 -> args0 }).orElse(null),
                destinationCidr = javaType.destinationCidr().map({ args0 -> args0 }).orElse(null),
                prefixListId = javaType.prefixListId().map({ args0 -> args0 }).orElse(null),
                resourceId = javaType.resourceId().map({ args0 -> args0 }).orElse(null),
                resourceType = javaType.resourceType().map({ args0 -> args0 }).orElse(null),
                routeOrigin = javaType.routeOrigin().map({ args0 -> args0 }).orElse(null),
                state = javaType.state().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property attachmentId
 * @property destinationCidr
 * @property prefixListId
 * @property resourceId
 * @property resourceType
 * @property routeOrigin
 * @property state
 */
public data class NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute(
    public val attachmentId: String? = null,
    public val destinationCidr: String? = null,
    public val prefixListId: String? = null,
    public val resourceId: String? = null,
    public val resourceType: String? = null,
    public val routeOrigin: String? = null,
    public val state: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute): NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute =
            NetworkInsightsAnalysisReturnPathComponentTransitGatewayRouteTableRoute(
                attachmentId = javaType.attachmentId().map({ args0 -> args0 }).orElse(null),
                destinationCidr = javaType.destinationCidr().map({ args0 -> args0 }).orElse(null),
                prefixListId = javaType.prefixListId().map({ args0 -> args0 }).orElse(null),
                resourceId = javaType.resourceId().map({ args0 -> args0 }).orElse(null),
                resourceType = javaType.resourceType().map({ args0 -> args0 }).orElse(null),
                routeOrigin = javaType.routeOrigin().map({ args0 -> args0 }).orElse(null),
                state = javaType.state().map({ args0 -> args0 }).orElse(null),
            )
    }
}
